@@ -491,26 +491,22 @@ construction time.  It also requires and that the code which uses it is be wise
 about calling methods to send and recieve data which do not cause it to block
 indefinitely. :)
 
-=back
-
 =head1 METHODS
 
-=over 4
-
-=item new()
+=head2 new()
   
  $n = RMI::Node->new(reader => $fh1, writer => $fh2);
 
 The constructor for RMI::Node objects requires that a reader and writer handle be provided.  They
 can be the same handle if the handle is bi-directional (as with TCP sockets, see L<RMI::Client::Tcp>).
 
-=item close()
+=head2 close()
 
  $n->close();
 
 Closes handles, and does any additional required bookeeping.
  
-=item send_request_and_recieve_response()
+=head2 send_request_and_recieve_response()
 
  @result = $n->send_request_and_recieve_response($call_type,$object,$method,$params,$opts)
 
@@ -532,7 +528,7 @@ This method sends a method call request through the writer, and waits on a respo
 It will handle a response with the answer, exception messages, and also handle counter-requests
 from the server, which may occur b/c the server calls methods on objects passed as parameters.
 
-=item receive_request_and_send_response()
+=head2 receive_request_and_send_response()
 
 This method waits for a single request to be received from its reader handle, services
 the request, and sends the results through the writer handle.
@@ -540,7 +536,7 @@ the request, and sends the results through the writer handle.
 It is possible that, while servicing the request, it will make counter requests, and those
 counter requests, may yield counter-counter-requests which call this method recursively.
 
-=item virtual_lib()
+=head2 virtual_lib()
 
 This method returns an anonymous subroutine which can be used in a "use lib $mysub"
 call, to cause subsequent "use" statements to go through this node to its partner.
@@ -551,8 +547,6 @@ call, to cause subsequent "use" statements to go through this node to its partne
 If a client is constructed for other purposes in the application, the above
 can also be accomplished with: $client->use_lib_remote().  (See L<RMI::Client>)
 
-=back
-    
 =head1 INTERNALS
 
 The RMI internals are built around sending a "message", which has a type, and an
@@ -561,9 +555,7 @@ type.
 
 The following message types are passed within the current implementation:
 
-=over 2
-
-=item query
+=head2 query
 
 A request that logic execute on the remote side on behalf of the sender.
 This includes object method calls, class method calls, function calls,
@@ -590,28 +582,26 @@ The message data contains, in order:
  - ...          The next parameter to the function/method call
 
 
-=item result
+=head2 result
 
 The return value from a succesful "query" which does not result in an
 exception being thrown on the remote side.
   
 The message data contains, the return value or vaues of that query.
   
-=item exception
+=head2 exception
 
 The response to a query which resulted in an exception on the remote side.
   
 The message data contains the value thrown via die() on the remote side.
   
-=item close
+=head2 close
 
 Indicatees that the remote side has closed the connection.  This is actually
 constructed on the receiver end when it fails to read from the input stream.
   
 The message data is undefined in this case.
   
-=back
-
 The _send() and _receive() methods are symmetrical.  These two methods are used
 by the public API to encapsulate message transmission and reception.  The _send()
 method takes a message_type and a message_data arrayref, and transmits them to
@@ -627,9 +617,7 @@ value in the same format into a message_type and message_data array.
 
 The serialization process has two stages:
 
-=over 4
-
-=item replacing references with identifiers used for remoting
+=head2 replacing references with identifiers used for remoting
 
 An array of message_data of length n to is converted to have a length of n*2.
 Each value is preceded by an integer which categorizes the value.
@@ -655,15 +643,13 @@ Each value is preceded by an integer which categorizes the value.
 
 Note that all references are turned into primitives by the above process.
 
-=item stringification
+=head2 stringification
 
 The "wire protocol" for sending and receiving messages is to pass an array via Data::Dumper
 in such a way that it does not contain newlines.  The receiving side uses eval to reconstruct
 the original message.  This is terribly inefficient because the structure does not contain
 objects of arbitrary depth, and is parsable without tremendous complexity.
 
-=back
-
 Details on how proxy objects and references function, and pose as the real item
 in question, are in B<RMI>, and B<RMI::ProxyObject> and B<RMI::ProxyReference>
 
@@ -671,12 +657,44 @@ in question, are in B<RMI>, and B<RMI::ProxyObject> and B<RMI::ProxyReference>
 
 See general bugs in B<RMI> for general system limitations
 
+=head2 the serialization mechanism needs to be made more robust and efficient
+
+It's really just enough to "work".
+
+The current implementation uses Data::Dumper with options which should remove
+newlines.  Since we do not flatten arbitrary data structures, a simpler parser
+would be more efficient.
+
+The message type is currently a text string.  This could be made smaller.
+
+The data type before each paramter or return value is an integer, which could
+also be abbreviated futher, or we could go the other way and be more clear. :)
+
+This should switch to sysread and pass the message length instead of relying on
+buffers, since the non-blocking IO might not have issues.
+
 =head1 SEE ALSO
 
 B<RMI>, B<RMI::Server>, B<RMI::Client>, B<RMI::ProxyObject>, B<RMI::ProxyReference>
 
 B<IO::Socket>, B<Tie::Handle>, B<Tie::Array>, B<Tie:Hash>, B<Tie::Scalar>
 
+=head1 AUTHORS
+
+Scott Smith <sakoht@cpan.org>
+
+=head1 COPYRIGHT
+
+Copyright (c) 2008 - 2009 Scott Smith <sakoht@cpan.org>  All rights reserved.
+
+=head1 LICENSE
+
+This program is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
+
+The full text of the license can be found in the LICENSE file included with this
+module.
+
 =cut
 
 1;
